"""
Rawana package - Stories and powers of the mighty Rawana
"""

__version__ = "0.1.1"

from . import powers
from . import stories

# Initialize the Powers and Stories classes
powers = powers.Powers()
stories = stories.Stories()
